@@ -6,5 +6,6 @@ utils::globalVariables(c(
   "upr","upr.agg","use","use.cumm","val","val_smooth",
   "value","value_smooth","y",
   "t.diff", "t.diff.check", "check",
-  "silent", "x", "case_when"
+  "silent", "x", "case_when",
+  "chain", "iter", "parameter", "Point.est.", "Upper.C.I."
 ))
